@@ -1,9 +1,12 @@
 from . import enums, helpers
+from ._helpers import as_callable
 from .config import MISSING, CachedConfig, CIConfig, Config
 from .env import EnvMapping, LowerEnvMapping
+from .envconfig import EnvConfig
 from .exceptions import AlreadySet, InvalidCast, MissingName
 
 __all__ = [
+    'as_callable',
     'Config',
     'CachedConfig',
     'CIConfig',
@@ -12,6 +15,7 @@ __all__ = [
     'LowerEnvMapping',
     'MissingName',
     'InvalidCast',
+    'EnvConfig',
     'AlreadySet',
     'enums',
     'helpers',
