@@ -2,13 +2,29 @@ import typing
 from collections.abc import Callable
 from shlex import shlex
 
+from ._helpers import as_callable
+
 T = typing.TypeVar('T')
 
 
+@typing.overload
 def comma_separated(
-    cast: Callable[[str], T] = str
+    cast: Callable[[str], str] = as_callable(str)
+) -> typing.Callable[[str], tuple[str, ...]]:
+    ...
+
+
+@typing.overload
+def comma_separated(
+    cast: Callable[[str], T]
 ) -> typing.Callable[[str], tuple[T, ...]]:
-    def _wrapped(val: str) -> tuple[T, ...]:
+    ...
+
+
+def comma_separated(
+    cast: Callable[[str], T | str] = as_callable(str)
+) -> typing.Callable[[str], tuple[T | str, ...]]:
+    def _wrapped(val: str) -> tuple[T | str, ...]:
         lex = shlex(val, posix=True)
         lex.whitespace = ','
         lex.whitespace_split = True
